summaryrefslogtreecommitdiffstats
path: root/test/t/unit/test_unit_ip_addresses.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/t/unit/test_unit_ip_addresses.py')
-rw-r--r--test/t/unit/test_unit_ip_addresses.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/test/t/unit/test_unit_ip_addresses.py b/test/t/unit/test_unit_ip_addresses.py
index 8120c88..37f3b0e 100644
--- a/test/t/unit/test_unit_ip_addresses.py
+++ b/test/t/unit/test_unit_ip_addresses.py
@@ -9,41 +9,41 @@ class TestUnitIpAddresses:
def functions(self, request, bash):
assert_bash_exec(
bash,
- "_ia() { local cur=$(_get_cword);unset COMPREPLY;"
- "_ip_addresses; }",
+ "_ia() { local cur;_comp_get_words cur;"
+ "unset -v COMPREPLY;_comp_compgen_ip_addresses; }",
)
assert_bash_exec(bash, "complete -F _ia ia")
assert_bash_exec(
bash,
- "_iaa() { local cur=$(_get_cword);unset COMPREPLY;"
- "_ip_addresses -a; }",
+ "_iaa() { local cur;_comp_get_words cur;"
+ "unset -v COMPREPLY;_comp_compgen_ip_addresses -a; }",
)
assert_bash_exec(bash, "complete -F _iaa iaa")
assert_bash_exec(
bash,
- " _ia6() { local cur=$(_get_cword);unset COMPREPLY;"
- "_ip_addresses -6; }",
+ " _ia6() { local cur;_comp_get_words cur;"
+ "unset -v COMPREPLY;_comp_compgen_ip_addresses -6; }",
)
assert_bash_exec(bash, "complete -F _ia6 ia6")
def test_1(self, bash):
- assert_bash_exec(bash, "_ip_addresses")
+ assert_bash_exec(bash, "_comp_compgen_ip_addresses")
@pytest.mark.complete("iaa ")
def test_2(self, functions, completion):
"""_ip_addresses -a should complete ip addresses."""
assert completion
assert all("." in x or ":" in x for x in completion)
@pytest.mark.complete("ia ")
def test_3(self, functions, completion):
"""_ip_addresses should complete ipv4 addresses."""
assert completion
assert all("." in x for x in completion)
@pytest.mark.xfail(in_container(), reason="Probably fails in a container")
@pytest.mark.complete("ia6 ")
def test_4(self, functions, completion):
"""_ip_addresses -6 should complete ipv6 addresses."""
assert completion
assert all(":" in x for x in completion)
@@ -9,41 +9,41 @@ class TestUnitIpAddresses:
def test_2(self, functions, completion):
- """_ip_addresses -a should complete ip addresses."""
+ """_comp_compgen_ip_addresses -a should complete ip addresses."""
assert completion
assert all("." in x or ":" in x for x in completion)
@@ -9,41 +9,41 @@ class TestUnitIpAddresses:
def test_3(self, functions, completion):
- """_ip_addresses should complete ipv4 addresses."""
+ """_comp_compgen_ip_addresses should complete ipv4 addresses."""
assert completion
assert all("." in x for x in completion)
@@ -9,41 +9,41 @@ class TestUnitIpAddresses:
def test_4(self, functions, completion):
- """_ip_addresses -6 should complete ipv6 addresses."""
+ """_comp_compgen_ip_addresses -6 should complete ipv6 addresses."""
assert completion
assert all(":" in x for x in completion)